==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/id.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Pembagian terfederasi",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Apakah Anda ingin menambahkan pembagian remote {name} dari {owner}@{remote}?",
    "Remote share" : "Berbagi remote",
    "Remote share password" : "Sandi berbagi remote",
    "Cancel" : "Batalkan",
    "Add remote share" : "Tambah berbagi remote",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
    "Server to server sharing is not enabled on this server" : "Berbagi server ke server tidak diaktifkan pada server ini",
    "Couldn't establish a federated share." : "Tidak dapat mendirikan pembagian terfederasi",
    "Couldn't establish a federated share, maybe the password was wrong." : "Tidak dapat mendirikan pembagian terfederasi, mungkin sandi salah.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Permintaan pembagian terfederasi sukses, Anda akan mendapatkan undangan. Cek pemberitahuan Anda.",
    "The mountpoint name contains invalid characters." : "Nama mount point berisi karakter yang tidak sah.",
    "Not allowed to create a federated share with the owner." : "Tidak diizinkan membuat pembagian terfederasi dengan pemilik.",
    "Invalid or untrusted SSL certificate" : "Sertifikat SSL tidak sah atau tidak terpercaya",
    "Could not authenticate to remote share, password might be wrong" : "Tidak dapat mengautentikasi berbagi remote, kata sandi mungkin salah",
    "Storage not valid" : "Penyimpanan tidak sah",
    "Federated Share successfully added" : "Pembagian terfederasi sukses ditambahkan",
    "Couldn't add remote share" : "Tidak dapat menambahkan berbagi remote",
    "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
    "Not allowed to create a federated share with the same user" : "Tidak diizinkan membuat pembagian terfederasi dengan pengguna yang sama",
    "File is already shared with %s" : "Berkas sudah dibagikan dengan %s",
    "Could not find share" : "Tidak dapat mencari pembagian",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Dibagikan pada saya melalui #Nextcloud Federated Cloud ID saya, lihat %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dibagikan pada saya melalui #Nextcloud Federated Cloud ID saya",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Buka dokumentasi",
    "Allow users on this server to send shares to other servers" : "Izinkan para pengguna di server ini untuk mengirimkan berbagi ke server lainnya.",
    "Allow users on this server to receive shares from other servers" : "Izinkan para pengguna di server ini untuk menerima berbagi ke server lainnya.",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Federated Cloud ID Anda:",
    "Share it:" : "Bagikan:",
    "Add to your website" : "Tambahkan pada situs web Anda",
    "Share with me via Nextcloud" : "Dibagikan pada saya via Nextcloud",
    "HTML Code:" : "Kode HTML:",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Berbagi %s gagal, tidak menemukan %s, kemungkinan saat ini server tidak dapat dijangkau.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Anda menerima \"/%3$s\" sebagai berbagi remote dari %1$s (mewakili %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Anda menerima \"/%3$s\" sebagai berbagi remote dari %1$s"
},
"nplurals=1; plural=0;");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/id.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Pembagian terfederasi",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Apakah Anda ingin menambahkan pembagian remote {name} dari {owner}@{remote}?",
    "Remote share" : "Berbagi remote",
    "Remote share password" : "Sandi berbagi remote",
    "Cancel" : "Batalkan",
    "Add remote share" : "Tambah berbagi remote",
    "Copy" : "Salin",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
    "Server to server sharing is not enabled on this server" : "Berbagi server ke server tidak diaktifkan pada server ini",
    "Couldn't establish a federated share." : "Tidak dapat mendirikan pembagian terfederasi",
    "Couldn't establish a federated share, maybe the password was wrong." : "Tidak dapat mendirikan pembagian terfederasi, mungkin sandi salah.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "Permintaan pembagian terfederasi sukses, Anda akan mendapatkan undangan. Cek pemberitahuan Anda.",
    "The mountpoint name contains invalid characters." : "Nama mount point berisi karakter yang tidak sah.",
    "Not allowed to create a federated share with the owner." : "Tidak diizinkan membuat pembagian terfederasi dengan pemilik.",
    "Invalid or untrusted SSL certificate" : "Sertifikat SSL tidak sah atau tidak terpercaya",
    "Could not authenticate to remote share, password might be wrong" : "Tidak dapat mengautentikasi berbagi remote, kata sandi mungkin salah",
    "Storage not valid" : "Penyimpanan tidak sah",
    "Federated Share successfully added" : "Pembagian terfederasi sukses ditambahkan",
    "Couldn't add remote share" : "Tidak dapat menambahkan berbagi remote",
    "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
    "Not allowed to create a federated share with the same user" : "Tidak diizinkan membuat pembagian terfederasi dengan pengguna yang sama",
    "File is already shared with %s" : "Berkas sudah dibagikan dengan %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Berbagi %s gagal, tidak menemukan %s, mungkin peladen saat ini tidak dapat dicapai atau menggunakan sertifikat self-signed.",
    "Could not find share" : "Tidak dapat mencari pembagian",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Anda menerima \"%3$s\" sebagai berbagi jauh dari %1$s (atas nama %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Anda menerima {share} sebagai berbagi jauh dari {user} (atas nama {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Anda menerima \"%3$s\" sebagai berbagi jauh dari %1$s",
    "You received {share} as a remote share from {user}" : "Anda menerima {share} sebagai berbagi jauh dari {user}",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Dibagikan pada saya melalui #Nextcloud Federated Cloud ID saya, lihat %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dibagikan pada saya melalui #Nextcloud Federated Cloud ID saya",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Buka dokumentasi",
    "Allow users on this server to send shares to other servers" : "Izinkan para pengguna di server ini untuk mengirimkan berbagi ke server lainnya.",
    "Allow users on this server to receive shares from other servers" : "Izinkan para pengguna di server ini untuk menerima berbagi ke server lainnya.",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Federated Cloud ID Anda:",
    "Share it:" : "Bagikan:",
    "Add to your website" : "Tambahkan pada situs web Anda",
    "Share with me via Nextcloud" : "Dibagikan pada saya via Nextcloud",
    "HTML Code:" : "Kode HTML:",
    "Search global and public address book for users" : "Cari alamat buku global dan alamat publik untuk pengguna"
},
"nplurals=1; plural=0;");
